@@ -207,7 +207,7 @@ def VIEWS(app):
 # \t\texcept Exception as e:
 # \t\t\treturn JsonResponse(False, safe=False)
 # \treturn JsonResponse(False, safe=False)
-    return '\n\n'.join(defs)
+    return '\n'.join(defs)
 
 
 def MODELS(app):
@@ -291,17 +291,3 @@ def REQUIREMENTS():
 
 def README():
     return """"""
-
-
-# class User(models.Model):
-# 	id = models.UUIDField(primary_key=True, unique=True, editable=False, max_length=21, default=uuid.uuid4, auto_created=True)
-# 	f_name = models.CharField(max_length=255, null=True, blank=True, unique=False)
-# 	l_name = models.CharField(max_length=255, null=True, blank=True, unique=False)
-# 	created_at = models.DateTimeField(default=timezone.now, null=False, blank=False, unique=False)
-# 	class Meta:
-# 		app_label = "API"
-
-# from django.apps import AppConfig
-
-# class AppConfig(AppConfig):
-# 	name = 'API'
\ No newline at end of file
